% M203_1_settings.m
% settings for CTD calibration

allsettings = add_cruise_info;
cruise_info
allsettings.release = 0;
allsettings.release_history = '0: test release';
allsettings.quality_control_indicator = '5';
allsettings.quality_index = '0';
allsettings.comment = '';

allsettings.uncertainty.t = 0.002;
allsettings.uncertainty.s = 0.003;
allsettings.uncertainty.p = 2;
allsettings.uncertainty.o = 1.5;

allsettings.loopedit = 0.00;
allsettings.loopedit_exception = [];
allsettings.use_dens1_loopedit = 1;
allsettings.use_dens2_loopedit = 0;

allsettings.use_system_upload_time = 0;

allsettings.start_scan = []; % 
allsettings.do_not_write_down_data_write_up_in_down_file_instead = []; %

% override start_scan of profiles (determined in step 1)
% enter pairs [profile_number,first_good_scan]

allsettings.sbepre_filename = 'met_203_1_';
allsettings.crsid_long = 'Meteor 203/1';
allsettings.crsid = 'met_203_1';
allsettings.cruise_leg = '1';
allsettings.aligndepthrange = [600,800];
allsettings.alignsigns = [1,-1];		% for C and for O
allsettings.sbepre_addname = '';
allsettings.print_format = 'jpg';

allsettings.autosal_deviation_range = [-0.05,0.05];


%allsettings.bsh_ref = '';    
allsettings.author = 'Gerd Krahmann';
allsettings.contact = 'gkrahmann@geomar.de';


allsettings.yoyo=[];
allsettings.do_not_write_up_file = [];
allsettings.lonlat = [];
allsettings.lonlat = [];
allsettings.use_davis_nav = [];  % This should be empty and
                                      % is only used for station 54 and 55
                                      % of MSM182, where NMEA was
                                      % not recorded in .cnv file

% load sensor SNs and create settings
if ~exist(['mat/',allsettings.crsid,'_sensors.mat'])
  sensor = get_sensors(allsettings.crsid,allsettings.sbepre_addname);
else
  load(['mat/',allsettings.crsid,'_sensors.mat'])
end


pri_c = unique(sensor.pri_c_setup);
pri_c = pri_c(find(~isnan(pri_c)));
sec_c = unique(sensor.sec_c_setup);
sec_c = sec_c(find(~isnan(sec_c)));
pri_o = unique(sensor.pri_o_setup);
pri_o = pri_o(find(~isnan(pri_o)));
sec_o = unique(sensor.sec_o_setup);
sec_o = sec_o(find(~isnan(sec_o)));
ctd = unique(sensor.ctd_setup);
ctd = ctd(find(~isnan(ctd)));

% Mail from Gerd related to deep oxygen values where no Winkler values were
% available:
% Falls Du eine quadratische Kalibrierung in p verwendest, dann solltest Du sie in so einem Fall (keine tiefe Proben
% und ausgedehnte Extrapolation) auf linear setzen. Da gibt es so einen (sogar zwei) Vektor mit
% [2,1,0,1,0,0,1]
% [p,t,c,o,tim,chl,p*o] bis-zu Ordnung der Koeffizienten
% den auf [1,1,0,1,0,0,1] 
% oder sogar [1,1,0,1,0,0,0]
% setzen.


for n=1:length(pri_c)
  pri_c_settings(pri_c(n)).prof = sensor.prof(find(pri_c(n)==sensor.pri_c_setup));
  pri_c_settings(pri_c(n)).apply2prof = sensor.prof(find(pri_c(n)==sensor.pri_c_setup));
  pri_c_settings(pri_c(n)).c_std = 0.333;               
  pri_c_settings(pri_c(n)).c_meth = 'f'; 
  pri_c_settings(pri_c(n)).c_exps = [1,1,1,0,0,0,0];   % [p,t,c,o,tim,chl,p*o] 
end
for n=1:length(pri_o)
  pri_o_settings(pri_o(n)).prof = sensor.prof(find(pri_o(n)==sensor.pri_o_setup));
  pri_o_settings(pri_o(n)).apply2prof = sensor.prof(find(pri_o(n)==sensor.pri_o_setup));
  pri_o_settings(pri_o(n)).o_std = 0.333;               
  pri_o_settings(pri_o(n)).o_meth = 'f'; 
  pri_o_settings(pri_o(n)).o_exps = [1,1,0,1,0,0,1];   
end

for n=1:length(ctd)
  ctd_settings(ctd(n)).prof = sensor.prof(find(ctd(n)==sensor.ctd_setup));
  ctd_settings(ctd(n)).apply2prof = sensor.prof(find(ctd(n)==sensor.ctd_setup));
  ctd_settings(ctd(n)).p_offset = 0;               
  ctd_settings(ctd(n)).chl_offset = 0;               
end
for n=1:length(sec_c)
  sec_c_settings(sec_c(n)).prof = sensor.prof(find(sec_c(n)==sensor.sec_c_setup));
  sec_c_settings(sec_c(n)).apply2prof = sensor.prof(find(sec_c(n)==sensor.sec_c_setup));
  sec_c_settings(sec_c(n)).c_std = 0.333;               
  sec_c_settings(sec_c(n)).c_meth = 'f'; 
  sec_c_settings(sec_c(n)).c_exps = [1,1,1,0,0,0,0];   
end
for n=1:length(sec_o)
  sec_o_settings(sec_o(n)).prof = sensor.prof(find(sec_o(n)==sensor.sec_o_setup));
  sec_o_settings(sec_o(n)).apply2prof = sensor.prof(find(sec_o(n)==sensor.sec_o_setup));
  sec_o_settings(sec_o(n)).o_std = 0.333;               
  sec_o_settings(sec_o(n)).o_meth = 'f'; 
  sec_o_settings(sec_o(n)).o_exps = [1,1,0,1,0,0,1];   
end

% $$$ set_cal(1).o_down_sec_str = '4.1019-0.00058408*p-0.48891*t+0.061793*o';

%set_delay.o_pri(1) = 3;
%set_delay.o_sec(1) = 3;
% set_delay.o_pri(3) = 3.68;
% set_delay.o_pri(4) = 3.68;
% set_delay.c.pri(1:54) = 0.04/86400;
% set_delay.c.pri(55:70) = -0.03/86400;
% set_delay.c.sec(1:54) = 0.05/86400;
% set_delay.c.sec(55:70) = -0.02/86400;
% set_delay.c.comment = 'Deck unit was swapped after CTD 54. New unit had a different internal delay setting.';

% insert 'median' from final plot in step 1
% this will remove deck pressure
%
% <---------- Hier anpassen  p_offset
ctd_settings(1).p_offset = 0.3;
ctd_settings(1).chl_offset = 0;


% <---------- Hier anpassen  [1:bis Dein letztes Profil]

use_settings(1).apply2prof = [1:82];  % CHANGE!!!

% <---------- Hier anpassen  select sensors for final data]
% Three element vector of which sensor shall be used for [temperature,
% conductivity, oxygen]. The values can be either 1 (to use the primary
% sensors) or 2 (to use the secondary sensors). Only as very rare
% excemptions should sensors from different strings be mixed.
use_settings(1).use_sensor = 2*[1,1,1]; % 



% ctd_settings(2).p_offset = 0.99;
% ctd_settings(2).chl_offset = 0.035;
% 
% use_settings(2).apply2prof = [1:13];
% use_settings(2).apply2prof = [1:13];
% use_settings(2).use_sensor = [1,1,1];



% what to set for sensor calibration
%  _f = 's' for outlier selection by std criterion (in _std)
%  _f = 'f' for outlier selection by fraction of data criterion (in _std)
%  _exps =   degree of polynom in [press, temp, cond, oxyf, time,chl]
 
% which variables to write into calibrated files
% choose from
% p    pressure
% z    depth
% t    in situ temperature
% s    salinity
% okg  oxygen in umol/kg
% chl  chlorophyl in ug/l
% c    conductivity
% sig  in situ density
% ss   sound speed
% sth  sigma theta
% tim  time in Matlab datenum units
%allsettings.write_prof_vars = {'tim','lon','lat','p','z','t','s','o','ss','sth','chl2_raw','turb_raw','cdom_raw','cdom2_raw','par'};
allsettings.write_prof_vars = {'tim','lon','lat','p','z','t','s','o','ss','sth','par','chl2_raw','turb_raw'};
% allsettings.write_prof_vars = {'tim','lon','lat','p','z','t','s','o','ss','sth','chl_raw','turb_raw','nox'};
allsettings.write_time_vars = {'tim','p','t','s','c','o','lat','lon'};

% btl_down 1: pressure only;(fastest) 2: pressure and closest temperature
%          3: best vertical shift of up temperature profile (slow but good)
allsettings.btl_down = 2; 
allsettings.btl_down_tshift = [1:50];   % delta p for shift, prange for shift
allsettings.btl_down_sensor = 2;  % use primary or secondary to pick
                                  % down bottle equivalents

                    
                   
%
% define which calibrated rodbfiles are to be written
% give a vector of the types
%
% 1: regular 1 dbar file
% 2: upcast 1 dbar file
% 3: 1 second binned full cast file
% 4: full data rate full cast file
allsettings.which_file_types = [1,2,3];

% mark bad scans
% allsettings.bad_c_1_scans = [[15,69395,69405];[15,69470,69490];[15,69860,69871];[15,70050,70067];...
%   [15,70120,70130];[15,70325,70330];[15,70385,70400];[15,70985,70995];[15,71045,71055];[15,71625,71640];...
%   [15,71920,71935];[15,71950,71965];[15,72018,72022];[19,169905,169915];[19,170415,170425];...
%   [19,170520,170530];[19,170655,170665];[19,170670,170675];[19,170715,170730];...
%   [19,170774,170778];[19,171022,171028];[23,29210,29420];[25,117850,117855];[25,117887,117893];...
%   [25,117986,117988];[25,118005,118010];...
%   [25,118090,118120];[25,118170,118174];[25,118183,118185];[25,118225,118227];...
%   [25,118233,118238];[25,118350,118367];[25,118402,118404];[25,118430,118436];...
%   [25,118440,118452];[25,118490,118497];...
%   [25,118521,118535];[25,118619,118622];[25,118633,118666];[25,118746,118752];[25,118753,118756];...
%   [25,119340,119350];[25,119818,119824];[25,119968,119972];[49,106349,106356];...
%   [49,106360,106365];[49,106390,106450];[49,106655,106670];[49,106740,106747];...
%   [49,106840,106865]];
%allsettings.bad_c_2_scans = [[15,69395,69405];[15,70985,70995];[15,71350,71360];[19,169885,169895];...
%   [19,169905,169910];[19,169846,169850];[19,170405,170415];[19,170670,170675];...
%   [19,170776,170782];[25,117850,117856];[25,117884,117890];[25,117928,117933];...
%   [25,117938,117943];[25,118048,118050];[25,118233,118238];[25,118280,118284];...
%   [25,118393,118395];[25,118427,118446];[25,118515,118534];[25,118592,118594];[25,118619,118624];...
%   [25,118706,118710];[25,118744,118748];[25,118753,118756];[25,118954,118958];...
%   [25,118328,118332];[49,106346,106354];[49,106358,106367];[49,106415,106425];...
%   [49,106620,106630];[49,106655,106675];[49,106710,106720];[49,106850,106865]];
% allsettings.bad_c_1_scans = [[12,1,255304];[12,230650,255304]];
% allsettings.bad_c_2_scans = [[12,212000,212400]];
% allsettings.bad_t_1_scans = [[12,230500,255304]];
% allsettings.bad_t_2_scans = [[12,230500,255304]];
%allsettings.bad_c_1_scans = [[4,68000,122000]];
% allsettings.bad_o_1_scans = [[15,70390,70460];[15,70055,70065];[15,70095,70160];[15,108654,108666];...
%   [15,70980,71040];[21,52170,52230];[25,118050,232072];[49,106600,106950];[49,107400,107500];...
%   [49,120600,120700];[55,129000,129100];[63,48820,48880]];
% allsettings.bad_o_1_scans = [[12,212000,255304]];
% allsettings.bad_o_2_scans = [[3,64300,64500];[12,1,255304];[22,121800,122400]];

%allsettings.bad_o_1_scans = [[87,1,3200]];
%allsettings.bad_o_2_scans = [[87,1,3200];[96,20400,21180]];
%allsettings.bad_c_2_scans = [[31,42690,42737];[31,46635,46645];[96,20400,21180]];
%allsettings.bad_o_2_scans = [33,1,26775];
%allsettings.bad_o_1_scans = [34,1,238679];

allsettings.area = 'Atlantic';

%allsettings.tsal.s1_time_chunks = [-1000,1000];
%allsettings.tsal.s2_time_chunks = [-1000,1000];
%allsettings.tsal.comment = '';

